@@ -31,6 +31,7 @@ import sanlock
 
 from . import constants
 from ..env import config
+from ..env import config_constants as const
 from ..lib import brokerlink
 from ..lib import engine
 from ..lib import exceptions as ex
@@ -181,7 +182,7 @@ class HostedEngine(object):
 
     @property
     def min_memory_threshold(self):
-        return int(self._config.get(config.VM, config.MEM_SIZE))
+        return int(self._config.get(config.VM, const.MEM_SIZE))
 
     def _get_score_config(self):
         score = {
@@ -266,7 +267,7 @@ class HostedEngine(object):
             'monitor': 'ping',
             'type': float,
             'options': {
-                'addr': self._config.get(config.ENGINE, config.GATEWAY_ADDR)}
+                'addr': self._config.get(config.ENGINE, const.GATEWAY_ADDR)}
         })
         req.append({
             'field': 'bridge',
@@ -274,9 +275,9 @@ class HostedEngine(object):
             'type': bool,
             'options': {
                 'address': '0',
-                'use_ssl': self._config.get(config.ENGINE, config.VDSM_SSL),
+                'use_ssl': self._config.get(config.ENGINE, const.VDSM_SSL),
                 'bridge_name': self._config.get(
-                    config.ENGINE, config.BRIDGE_NAME
+                    config.ENGINE, const.BRIDGE_NAME
                 )}
         })
         req.append({
@@ -285,7 +286,7 @@ class HostedEngine(object):
             'type': float_or_none,
             'options': {
                 'address': '0',
-                'use_ssl': self._config.get(config.ENGINE, config.VDSM_SSL)}
+                'use_ssl': self._config.get(config.ENGINE, const.VDSM_SSL)}
         })
         req.append({
             'field': 'cpu-load',
@@ -293,8 +294,8 @@ class HostedEngine(object):
             'type': float_or_none,
             'options': {
                 'address': '0',
-                'use_ssl': self._config.get(config.ENGINE, config.VDSM_SSL),
-                'vm_uuid': self._config.get(config.ENGINE, config.HEVMID)}
+                'use_ssl': self._config.get(config.ENGINE, const.VDSM_SSL),
+                'vm_uuid': self._config.get(config.ENGINE, const.HEVMID)}
         })
         req.append({
             'field': 'engine-health',
@@ -302,15 +303,15 @@ class HostedEngine(object):
             'type': engine_status,
             'options': {
                 'address': '0',
-                'use_ssl': self._config.get(config.ENGINE, config.VDSM_SSL),
-                'vm_uuid': self._config.get(config.ENGINE, config.HEVMID)}
+                'use_ssl': self._config.get(config.ENGINE, const.VDSM_SSL),
+                'vm_uuid': self._config.get(config.ENGINE, const.HEVMID)}
         })
         req.append({
             'field': 'storage-domain',
             'monitor': 'storage-domain',
             'type': bool,
             'options': {
-                'sd_uuid': self._config.get(config.ENGINE, config.SD_UUID)
+                'sd_uuid': self._config.get(config.ENGINE, const.SD_UUID)
             }
         })
         return req
@@ -320,7 +321,7 @@ class HostedEngine(object):
         if self._host_id is not None:
             return self._host_id
 
-        host_id = self._config.get(config.ENGINE, config.HOST_ID)
+        host_id = self._config.get(config.ENGINE, const.HOST_ID)
         return int(host_id) if host_id else None
 
     @property
@@ -328,7 +329,7 @@ class HostedEngine(object):
         """Hosted engine is configured when host id is present and the
            configured value is not explicitly set to False
         """
-        configured = self._config.get(config.ENGINE, config.CONFIGURED)
+        configured = self._config.get(config.ENGINE, const.CONFIGURED)
         return self.host_id and (configured is None or configured == "True")
 
     def publish(self, state):
@@ -761,9 +762,10 @@ class HostedEngine(object):
             data["local"][field] = ret
 
         # check local maintenance
+        self._config.refresh_local_conf_file(config.HA)
         data["local"]["maintenance"] = util.to_bool(self._config.get(
             config.HA,
-            config.LOCAL_MAINTENANCE))
+            const.LOCAL_MAINTENANCE))
 
         self._log.debug("Refresh complete")
 
@@ -811,7 +813,7 @@ class HostedEngine(object):
         return md
 
     def _start_migration(self, host_id, hostname):
-        vm_id = self._config.get(config.VM, config.VM_UUID)
+        vm_id = self._config.get(config.VM, const.VM_UUID)
         self._log.debug("Initiating online migration of"
                         " vm %s from localhost to %s",
                         vm_id, hostname)
@@ -879,7 +881,7 @@ class HostedEngine(object):
         return False
 
     def _monitor_migration(self):
-        vm_id = self._config.get(config.VM, config.VM_UUID)
+        vm_id = self._config.get(config.VM, const.VM_UUID)
         self._log.debug("Monitoring migration of vm %s", vm_id)
         cli = util.connect_vdsm_json_rpc(
             logger=self._log
@@ -960,7 +962,7 @@ class HostedEngine(object):
         an exception indicating the error.
         """
         self._log.info("Ensuring VDSM state is clear for engine VM")
-        vm_id = self._config.get(config.VM, config.VM_UUID)
+        vm_id = self._config.get(config.VM, const.VM_UUID)
 
         for i in range(0, 10):
             # Loop until state is clear or until timeout
